@@ -720,10 +720,10 @@ is_fastboot_active() {
 # This function does not actually belong here; it is duct-tape solution
 # for #901289.
 logsave_best_effort() {
-	if [ -x /sbin/logsave ] && [ -e "${FSCK_LOGFILE}" ]; then
+	if [ -x /sbin/logsave ]; then
 		logsave -s "${FSCK_LOGFILE}" "$@"
 	else
-		log_failure_msg "Cannot persist the following output on disc"
+		log_warning_msg "Cannot persist the following output on disc"
 		"$@"
 	fi
 }
